<?php namespace EwTools\Models;

use EwTools\Support\Fluent;
use EwTools\Support\Str;
use WP_Post;

/**
 * Everyboard
 *
 * @link    http://infomaker.se
 * @package EwTools\Models
 * @since   EwTools\Models\Everyboard 0.1
 */
class Everyboard extends Fluent {
    
    /**
     * Defaults for fetching pages in Wordpress
     *
     * @var array
     */
    protected static $default_options = [
        'sort_order'   => 'ASC',
        'sort_column'  => 'post_title',
        'hierarchical' => true,
        'exclude'      => '',
        'include'      => '',
        'meta_key'     => '',
        'meta_value'   => '',
        'authors'      => '',
        'child_of'     => 0,
        'parent'       => -1,
        'exclude_tree' => '',
        'number'       => '',
        'offset'       => 0,
        'post_type'    => 'everyboard',
        'post_status'  => 'publish'
    ];
    
    /**
     * Page constructor.
     *
     * @since 0.1
     *
     * @param array $post
     */
    public function __construct( $post = [] ) {
        
        if( $post instanceof WP_Post ) {
            $post = array_change_key_case( $post->to_array(), CASE_LOWER );
        }
        
        $this->fill( $post );
    }
    
    /**
     * Retrieve page by post
     *
     * @param WP_Post $post
     *
     * @since 0.1
     * @return static
     */
    public static function createFromPost( WP_Post $post ) {
        return new static( array_change_key_case( $post->to_array(), CASE_LOWER ) );
    }
    
    /**
     * Retrieve Everyboard by id
     *
     * @param $id
     *
     * @since 0.1
     * @return static
     */
    public static function createFromId( $id ) {
        if( false !== ( $post = WP_Post::get_instance( $id ) ) ) {
            return static::createFromPost( $post );
        }
        return null;
    }
    
    /**
     * Return the board title
     *
     * @since 0.1
     * @return void
     */
    public function title() {
        $title = $this->post_title;
        
        return $title;
    }
    
    /**
     * Retrieve the data stored on a specific meta key
     *
     * @param string $key
     * @param mixed  $default
     *
     * @since 0.1
     * @return mixed
     */
    public function getMeta( $key = '', $default = [] ) {
        if( Str::isEmpty( $key ) ) {
            return get_post_meta( $this->id, $key, true );
        }
        $meta = json_decode( get_post_meta( $this->id, $key, true ), true );
        
        return $meta ? $meta : $default;
    }
    
    /**
     * Retrieve the url to the board edit page
     *
     * @since 0.1
     * @return false|string
     */
    public function editUrl() {
        return get_edit_post_link( $this->id );
    }
    
    /**
     * Retrieve the content of the board in the form of an array or json string if specified
     *
     * @param bool $to_array
     *
     * @since 0.1
     * @return void
     */
    public function boardContent( $to_array = false ) {
        $content = $this->getMeta( 'everyboard_json', '' );
        if( $to_array ) {
            $content = Str::notEmpty( $content ) ? json_decode( $content, true ) : [];
        }
        
        return $content;
    }
}