<?php namespace EwTools\Twig;

use EwTools\Storage\Cache;
use Twig_Cache_Filesystem;
use Twig_CacheInterface;

/**
 * CacheLoader
 *
 * @link    http://infomaker.se
 * @package EwTools\Twig
 * @since   EwTools\Twig\CacheLoader 0.1
 */
class ObjectCacheSystem extends Twig_Cache_Filesystem implements Twig_CacheInterface {
    
    /**
     * Add suffix so we don't have to delete it in deploy every time
     *
     * @var string
     */
    private static $cache_key = '';
    
    /**
     * Time in seconds to cache the output
     *
     * @var int
     */
    private static $cache_time = 360;
    
    /**
     * Writes the compiled template to cache.
     *
     * @param string $key     The cache key
     * @param string $content The template representation as a PHP class
     *
     * @since 0.1
     * @return void
     */
    public function write( $key, $content ) {
        Cache::set( $this->getCacheKey($key), serialize( $content ), static::$cache_time );
    }
    
    /**
     * Loads a template from the cache.
     *
     * @param string $key The cache key
     *
     * @since 0.1
     * @return void
     */
    public function load( $key ) {
        if( false !== ($content = Cache::get( $this->getCacheKey($key) )) ) {
            eval( '?>' . unserialize( $content ) );
        }
    }
    
    /**
     * Create a cache key combined with the key prefix provided
     * during setup and a hashed version of the native key provided by Twig
     *
     * @param $key
     *
     * @since 0.1
     * @return string
     */
    protected function getCacheKey( $key ) {
        return static::$cache_key . "_". md5($key);
    }
    
    /**
     * Static function for initialization
     *
     * @since 0.1
     *
     * @param string $cache_key_prefix
     * @param int $cache_time
     *
     * @return static
     */
    public static function setup($cache_key_prefix, $cache_time=60) {
        static::$cache_key = $cache_key_prefix;
        static::$cache_time = $cache_time;
        
        return new static(static::$cache_key);
    }
}